/* ------------------------------------------------------------------------ */
/*                                                                          */
/*  Copyright (C)                                                           */
/*                                                                          */
/*  This program is free software; you can redistribute it and/or modify    */
/*  it under the terms of the GNU General Public License as published by    */
/*  the Free Software Foundation; either version 2 of the License, or       */
/*  (at your option) any later version.                                     */
/*                                                                          */
/*  This program is distributed in the hope that it will be useful, but     */
/*  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANT-    */
/*  ABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General        */
/*  Public License for more details.                                        */
/*                                                                          */
/*  You should have received a copy of the GNU General Public License along */
/*  with this program; if not, write to the Free Software Foundation, Inc., */
/*  59 Temple Place, Suite 330, Boston, MA 02111-1307 USA                   */
/*                                                                          */
/* ------------------------------------------------------------------------ */
/*  $Author: vogje02 $ $Revision: 1.6 $ $Date: 2002/07/28 17:13:20 $        */
/* ------------------------------------------------------------------------ */

#include "stdafx.h"
#include "time.h"
#include "nmapwin.h"
#include "servicepage.h"
#include "winsvc.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

extern COptions* options;

/////////////////////////////////////////////////////////////////////////////
// CServicePage property page

/**
 * Constructor
 */
CServicePage::CServicePage() : CPropertyPage(CServicePage::IDD)
{
	//{{AFX_DATA_INIT(CServicePage)
	//}}AFX_DATA_INIT

	// Not initialize yet
	init = false;
}

/**
 * Destructor
 */
CServicePage::~CServicePage()
{
}

void CServicePage::DoDataExchange(CDataExchange* pDX)
{
	CPropertyPage::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CServicePage)
	DDX_Control(pDX, IDC_CHECK4, m_immediately);
	DDX_Control(pDX, IDC_CHECK2, m_autostart);
	DDX_Control(pDX, IDC_CHECK6, m_sat);
	DDX_Control(pDX, IDC_CHECK13, m_fri);
	DDX_Control(pDX, IDC_CHECK8, m_thu);
	DDX_Control(pDX, IDC_CHECK14, m_wed);
	DDX_Control(pDX, IDC_CHECK3, m_tue);
	DDX_Control(pDX, IDC_CHECK9, m_mon);
	DDX_Control(pDX, IDC_CHECK1, m_sun);
	DDX_Control(pDX, IDC_DATETIMEPICKER2, m_starttime);
	DDX_Control(pDX, IDC_DATETIMEPICKER1, m_startdate);
	DDX_Control(pDX, IDC_EDIT4, m_slidertext2);
	DDX_Control(pDX, IDC_EDIT3, m_slidervalue);
	DDX_Control(pDX, IDC_COMBO1, m_intervalfactor);
	DDX_Control(pDX, IDC_SLIDER1, m_interval);
	//}}AFX_DATA_MAP

	if( !init ) {
		m_interval.SetRange( 0, 24, true );
		m_interval.SetTicFreq( 3 );
		
		m_intervalfactor.AddString( (LPCTSTR )"Minutes" );
		m_intervalfactor.InsertString( 1, (LPCTSTR )"Hours" );
		m_intervalfactor.InsertString( 2, (LPCTSTR )"Days" );
		m_intervalfactor.InsertString( 3, (LPCTSTR )"Weeks" );
		m_intervalfactor.InsertString( 4, (LPCTSTR )"Months" );
		m_intervalfactor.SelectString( 1, (LPCTSTR )"Hours" );

		m_interval.SetPos( 3 );
		m_slidervalue.SetWindowText( "3" );
		m_slidertext2.SetWindowText( "0                                                                12                                                                24" );

		SYSTEMTIME sTime;
		GetLocalTime( &sTime );
		sTime.wHour = 0;
		sTime.wMinute = 0;
		sTime.wSecond = 0;
		m_starttime.SetTime( &sTime );
		m_starttime.SetFormat( "HH:mm:ss" );

		init = true;
	}
}


BEGIN_MESSAGE_MAP(CServicePage, CPropertyPage)
	//{{AFX_MSG_MAP(CServicePage)
	ON_BN_CLICKED(IDC_BUTTON1, OnButton1)
	ON_BN_CLICKED(IDC_BUTTON3, OnButton3)
	ON_BN_CLICKED(IDC_BUTTON4, OnButton4)
	ON_BN_CLICKED(IDC_BUTTON5, OnButton5)
	ON_BN_CLICKED(IDC_BUTTON6, OnButton6)
	ON_CBN_SELENDOK(IDC_COMBO1, OnSelendokCombo1)
	ON_NOTIFY(NM_RELEASEDCAPTURE, IDC_SLIDER1, OnReleasedcaptureSlider1)
	ON_EN_CHANGE(IDC_EDIT3, OnChangeEdit3)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/**
 * Sets the fake status bar, for returning message
 * to the main window without wasting time on windows
 * message handling.
 */
void CServicePage::SetStatusBar( CEdit* status, CEdit* vstatus, CEdit* hostedit )
{
	m_statusbar = status;
	m_vstatus = vstatus;
	m_hostedit = hostedit;
}

/**
 * Sets the different pages, needed to update the current values,
 * after an update from the registry.
 */
void CServicePage::SetPages( CScanPage* scanPage, CDiscoverPage* discoverPage,
			 			     COptionsPage* optionsPage, CTimingPage* timingPage,
							 CFilesPage* filesPage, CWindowsPage* windowsPage )
{
	m_scanPage = scanPage;
	m_discoverPage = discoverPage;
	m_optionsPage = optionsPage;
	m_timingPage = timingPage;
	m_filesPage = filesPage;
	m_windowsPage = windowsPage;
}

/**
 * Parses the service arguments which are stored in the registry in the order:
 * hh:mm:ss: starttime
 * int:      interval
 * int:      factor
 * bool[7]:  days
 */
void CServicePage::ParseNMapArgs()
{
	char* token;

	token = strtok( nmapArgs, " " );

	while( token ) {

		// Scan method
		if( strstr( token, "-sT" ) )
			options->scanMode = MODE_CONNECT;
		else if( strstr( token, "-sS" ) )
			options->scanMode = MODE_SYN_STEALTH;
		else if( strstr( token, "-sF" ) )
			options->scanMode = MODE_FIN_STEALTH;
		else if( strstr( token, "-sP" ) )
			options->scanMode = MODE_PING_SWEEP;
		else if( strstr( token, "-sU" ) )
			options->scanMode = MODE_UDP_SCAN;
		else if( strstr( token, "-sN" ) )
			options->scanMode = MODE_NULL_SCAN;
		else if( strstr( token, "-sX" ) )
			options->scanMode = MODE_XMAS_TREE;
		else if( strstr( token, "-sO" ) )
			options->scanMode = MODE_IP_SCAN;
		else if( strstr( token, "-sA" ) )
			options->scanMode = MODE_ACK_TREE;
		else if( strstr( token, "-sW" ) )
			options->scanMode = MODE_WIN_SCAN;
		else if( strstr( token, "-sR" ) )
			options->scanMode = MODE_RPC_SCAN;
		else if( strstr( token, "-sL" ) )
			options->scanMode = MODE_LIST_SCAN;

		// Port range
		else if( strstr( token, "-p" ) ) {   
			options->portRangeB = true;
			sprintf( options->portRangeS, strtok( NULL, " " ) );
		}

		// Device
		else if( strstr( token, "-e" ) ) {   
			options->deviceB = true;
			sprintf( options->deviceS, strtok( NULL, " " ) );
		}

		// Source address
		else if( strstr( token, "-S" ) ) {   
			options->sAddressB = true;
			sprintf( options->sAddressS, strtok( NULL, " " ) );
		}

		// Decoy
		else if( strstr( token, "-D" ) ) {   
			options->decoyB = true;
			sprintf( options->decoyS, strtok( NULL, " " ) );
		}

		// Bounce
		else if( strstr( token, "-b" ) ) {   
			options->bounceB = true;
			sprintf( options->decoyS, strtok( NULL, " " ) );
		}

		// Source Port
		else if( strstr( token, "-g" ) ) {   
			options->portB = true;
			sprintf( options->portS, strtok( NULL, " " ) );
		}

		// Discover mode
		else if( strstr( token, "-PT -PI" ) )
			options->discMode = DISC_TCP_ICMP;
		else if( strstr( token, "-PT" ) ) {
			if( options->discMode == DISC_ICMP )
				options->discMode = DISC_TCP_ICMP;
			else
				options->discMode = DISC_TCP;
		}
		else if( strstr( token, "-PI" ) ) {
			if( options->discMode == DISC_TCP )
				options->discMode = DISC_TCP_ICMP;
			else
				options->discMode = DISC_ICMP;
		}
		else if( strstr( token, "-P0" ) )
			options->discMode = DISC_NONE;
		
		// General options
		else if( strstr( token, "-f" ) )
			options->fragB = true;
		else if( strstr( token, "-I" ) )
			options->identB = true;
		else if( strstr( token, "-R" ) )
			options->resolveAllB = true;
		else if( strstr( token, "-n" ) )
			options->resolveNotB = true;
		else if( strstr( token, "-F" ) )
			options->fastScanB = true;
		else if( strstr( token, "-O" ) )
			options->osDetectionB = true;
		else if( strstr( token, "-iR" ) )
			options->randomHostB = true;
		else if( strstr( token, "--resume" ) )
			options->resumeB = true;

		else if( strstr( token, "-d" ) )
			options->debugB = true;
		else if( strstr( token, "-vv" ) )
			options->veryVerboseB = true;
		else if( strstr( token, "-v" ) )
			options->verboseB = true;

		// Throttle
		else if( strstr( token, "-T" ) )
			sprintf( options->throttle, strtok( NULL, " ") );

		else if( strstr( token, "--host_timeout" ) ) {
			options->hostTimeoutB = true;
			sprintf( options->hostTimeout, strtok( NULL, " " ) );
		} else if( strstr( token, "--min_rtt_timeout" ) ) {
			options->minRttB = true;
			sprintf( options->minRtt, strtok( NULL, " " ) );
		} else if( strstr( token, "--max_rtt_timeout" ) ) {
			options->maxRttB = true;
			sprintf( options->maxRtt, strtok( NULL, " " ) );
		} else if( strstr( token, "--initial_rtt_timeout" ) ) {
			options->initialRttB = true;
			sprintf( options->initialRtt, strtok( NULL, " " ) );
		} else if( strstr( token, "--max_parallelism" ) ) {
			options->parallelB = true;
			sprintf( options->parallel, strtok( NULL, " " ) );
		} else if( strstr( token, "--scan_delay" ) ) {
			options->delayB = true;
			sprintf( options->delay, strtok( NULL, " " ) );
		}

		// Input/output files
		else if( strstr( token, "-iL" ) ) {
			options->infileB = true;
			sprintf( options->infile, strtok( NULL, "\"" ) );
		} else if( strstr( token, "-oN" ) ) {
			options->outfileB = true;
			options->outfileType = OUTFILE_NORMAL;
			sprintf( options->outfile, strtok( NULL, "\"" ) );
		} else if( strstr( token, "-oX" ) ) {
			options->outfileB = true;
			options->outfileType = OUTFILE_XML;
			sprintf( options->outfile, strtok( NULL, "\"" ) );
		} else if( strstr( token, "-oG" ) ) {
			options->outfileB = true;
			options->outfileType = OUTFILE_GREP;
			sprintf( options->outfile, strtok( NULL, "\"" ) );
		} else if( strstr( token, "-oA" ) ) {
			options->outfileB = true;
			options->outfileType = OUTFILE_ALL;
			sprintf( options->outfile, strtok( NULL, "\"" ) );
		} else if( strstr( token, "--append_output" ) ) {
			options->outfileAppend = true;
		} else if( strstr( token, "--win_nopcap" ) ) {
			options->winNoPcapB = true;
		} else if( strstr( token, "--win_noiphlpapi" ) ) {
			options->winNoHlpApiB = true;
		} else if( strstr( token, "--win_norawsock" ) ) {
			options->winNoRawSocketB = true;
		} else if( strstr( token, "--win_forcerawsock" ) ) {
			options->winForceRawSocketB = true;
		} else if( strstr( token, "--win_nt4route" ) ) {
			options->winNt4RouteB = true;
		} else if( strstr( token, "--win_trace" ) ) {
			options->winTraceB = true;
		} else {
		
			// Rest must be host name field
			sprintf( options->hostName, token );
			if( ( token = strtok( NULL, "\0" ) ) )
				strcat( options->hostName, token );
			else	
				break;
		}
		token = strtok( NULL, " \0" );
	}	

	// Set the new options
	m_scanPage->SetOptions();
	m_discoverPage->SetOptions();
	m_optionsPage->SetOptions();
	m_timingPage->SetOptions();
	m_filesPage->SetOptions();
	m_windowsPage->SetOptions();
	m_hostedit->SetWindowText( options->hostName );

	char cmd[1024];
	options->GetCommand( cmd );
	m_vstatus->SetWindowText( cmd );
}

/**
 * Parses the service arguments which are stored in the registry in the order:
 * hh:mm:ss: starttime
 * int:      interval
 * int:      factor
 * bool[7]:  days
 */
void CServicePage::ParseServiceArgs()
{
	char sTime[9];
	char* token = strtok( (char*)servArgs, " " );

	// Get the start time
	if( token )
		strcpy( sTime, token );
	if( token = strtok( NULL, " " ) ) {
		m_interval.SetPos( atoi( token ) );
		m_slidervalue.SetWindowText( token );
	}
	
	// Get the interval factor and set the scale
	// of the slider
	if( token = strtok( NULL, " " ) ) {
		m_intervalfactor.SetCurSel( atoi( token ) );
		OnSelendokCombo1();
	}

	for( int i = 0; i < 7; i++ ) {
		if( ( token = strtok( NULL, " " ) ) ) {
			switch(i) {
				case 0:	
				m_sun.SetCheck( atoi( token ) );
				break;
				case 1:
				m_mon.SetCheck( atoi( token ) );
				break;
				case 2:
				m_tue.SetCheck( atoi( token ) );
				break;
				case 3:
				m_wed.SetCheck( atoi( token ) );
				break;
				case 4:
				m_thu.SetCheck( atoi( token ) );
				break;
				case 5:
				m_fri.SetCheck( atoi( token ) );
				break;
				case 6:
				m_sat.SetCheck( atoi( token ) );
				break;
			}
		}
	}

	// Auto start flag
	if( ( token = strtok( NULL, " " ) ) )
		m_autostart.SetCheck( atoi( token ) );

	// Immediately flag
	if( ( token = strtok( NULL, " " ) ) )
		m_immediately.SetCheck( atoi( token ) );

	// Split up the time
	int hour, min, sec;
	CTime now = CTime::GetCurrentTime();
	token = strtok( sTime, ":" );
	if( token )
		hour = atoi( token );
	if( ( token = strtok( NULL, ":" ) ) )
		min = atoi( token );
	if( ( token = strtok( NULL, "\0" ) ) )
		sec = atoi( token );
	m_starttime.SetTime( new CTime( now.GetYear(), now.GetMonth(), now.GetDay(), hour, min, sec ) );
}

/**
 * Read in the registry values. Both key are read, NMapServArgs and 
 * NMapArgs. NMapServArgs contains the service parameter (startTime, 
 * interval, interval factor etc. NMapArgs the nmap parameters.
 */
bool CServicePage::GetRegistryArgs()
{
	int ret;
	HKEY hkey;
	char szKey[1024];

	*servArgs = '\0';
	*nmapArgs = '\0';

	// Set service the registry parameters. Try opening the registry key:
	// HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\nmapserv\Parameters
	strcpy(szKey, "SYSTEM\\CurrentControlSet\\Services\\NMap\\Parameters");

	if( ( ret = RegOpenKeyEx(HKEY_LOCAL_MACHINE, szKey, 0, KEY_READ, &hkey ) ) == ERROR_SUCCESS ) {

		// Yes we are installed
		DWORD dwType = REG_SZ;
		DWORD dwSize = 1024;
		
		// Get the nmap service arguments
		if( ( ret = RegQueryValueEx(hkey, "NmapServArgs", NULL, &dwType, (unsigned char*)servArgs, &dwSize ) ) != ERROR_SUCCESS ) {
			*servArgs = '\0';
			return false;

		} else {

			if( dwSize > sizeof( servArgs ) ) {
				*servArgs = '\0';
				return false;
			}
		}

		// Get the nmap arguments
		dwType = REG_SZ;
		dwSize = 1024;
		if( ( ret = RegQueryValueEx(hkey, "NmapArgs", NULL, &dwType, (unsigned char*)nmapArgs, &dwSize ) ) != ERROR_SUCCESS ) {
			*nmapArgs = '\0';
			return false;

		} else {

			if( dwSize > sizeof( nmapArgs ) ) {
				*nmapArgs = '\0';
				return false;
			}
		}

		RegCloseKey(hkey);
	}
	return true;
}

/**
 * Writes the registry values. Both key are written, NMapServArgs and 
 * NMapArgs. NMapServArgs contains the service parameter (startTime, 
 * interval, interval factor etc. NMapArgs the nmap parameters.
 */
void CServicePage::SetRegistryArgs()
{
	HKEY hkey;
	char szKey[1024], val[10];
	unsigned char servArgs[1024];

	// Get the start time
	CTime starttime;
	m_starttime.GetTime( starttime );
	sprintf( (char*)servArgs, "%s ", starttime.Format( "%H:%M:%S" ) );
	
	// Get the interval
	m_slidervalue.GetWindowText( val, 10 );
	strcat( (char*)servArgs, val );
	strcat( (char*)servArgs, " " );

	// Get interval factor
	sprintf( val, "%d", m_intervalfactor.GetCurSel() );
	strcat( (char*)servArgs, val );
	strcat( (char*)servArgs, " " );

	// Get the day selection
	if( IsDlgButtonChecked( IDC_CHECK1 ) ) strcat( (char*)servArgs, "1 " );
	else strcat( (char*)servArgs, "0 " );
	if( IsDlgButtonChecked( IDC_CHECK9 ) ) strcat( (char*)servArgs, "1 " );
	else strcat( (char*)servArgs, "0 " );
	if( IsDlgButtonChecked( IDC_CHECK3 ) ) strcat( (char*)servArgs, "1 " );
	else strcat( (char*)servArgs, "0 " );
	if( IsDlgButtonChecked( IDC_CHECK14 ) )	strcat( (char*)servArgs, "1 " );
	else strcat( (char*)servArgs, "0 " );
	if( IsDlgButtonChecked( IDC_CHECK8 ) ) strcat( (char*)servArgs, "1 " );
	else strcat( (char*)servArgs, "0 " );
	if( IsDlgButtonChecked( IDC_CHECK13 ) ) strcat( (char*)servArgs, "1 " );
	else strcat( (char*)servArgs, "0 " );
	if( IsDlgButtonChecked( IDC_CHECK6 ) ) strcat( (char*)servArgs, "1 " );
	else strcat( (char*)servArgs, "0 " );
	if( IsDlgButtonChecked( IDC_CHECK2 ) ) strcat( (char*)servArgs, "1 " );
	else strcat( (char*)servArgs, "0 " );
	if( IsDlgButtonChecked( IDC_CHECK4 ) ) strcat( (char*)servArgs, "1 " );
	else strcat( (char*)servArgs, "0 " );

	// Set service the registry parameters. Try opening the registry key:
	// HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\nmapserv\Parameters
	strcpy(szKey, "SYSTEM\\CurrentControlSet\\Services\\NMap\\Parameters");

	if( RegOpenKeyEx(HKEY_LOCAL_MACHINE, szKey, 0, KEY_WRITE|KEY_NOTIFY, &hkey ) == ERROR_SUCCESS ) {

		// Yes we are installed
		DWORD dwType = REG_SZ;
		DWORD dwSize = strlen( (char*)servArgs );
		if( RegSetValueEx( hkey, "NmapServArgs", NULL, dwType, servArgs, dwSize ) != ERROR_SUCCESS )
			MessageBox( "Could not set new service parameters!", "Set Service Parameters", 
						MB_OK|MB_ICONWARNING );

		// Set the service args
		dwType = REG_SZ;
		char cmd[1024];
		options->GetCommand( cmd );
		dwSize = strlen( cmd );
		if( RegSetValueEx( hkey, "NmapArgs", NULL, dwType, (unsigned char*)cmd, dwSize ) != ERROR_SUCCESS )
			MessageBox( "Could not set new nmap parameters!", "Set Service Parameters", 
						MB_OK|MB_ICONWARNING );

		RegCloseKey(hkey);
	}
}

/**
 * Get button pressed callback
 */
void CServicePage::OnButton1() 
{
	if(	GetRegistryArgs() ) {
		ParseServiceArgs();
		ParseNMapArgs();
	}
}

/**
 * Set button pressed callback
 */
void CServicePage::OnButton3() 
{
	SetRegistryArgs();
}

/**
 * Start the NMap service
 */
void CServicePage::OnButton4() 
{
	int ret;
	BOOL bResult = FALSE;

    // Open the Service Control Manager
    SC_HANDLE hSCM = ::OpenSCManager(NULL, // local machine
                                     NULL, // ServicesActive database
                                     SC_MANAGER_ALL_ACCESS); // full access
    if (hSCM) {

        // Try to open the service
        SC_HANDLE hService = ::OpenService( hSCM, "NMap", SERVICE_ALL_ACCESS );
        if (hService)  {
			StartService( hService, 0, NULL );
	        ::CloseServiceHandle(hSCM);
	        m_statusbar->SetWindowText( "NMap service started" );
		} else {
			ret = GetLastError();
			char msg[256];
			sprintf( msg, "Could not start service - error code: %d", ret );
			MessageBox( msg, "Start NMap Service", MB_OK|MB_ICONERROR );
	        ::CloseServiceHandle(hSCM);
		}
    }    
}

/**
 * Stop the NMap service
 */
void CServicePage::OnButton5() 
{
	int ret;
	BOOL bResult = FALSE;

    // Open the Service Control Manager
    SC_HANDLE hSCM = ::OpenSCManager(NULL, // local machine
                                     NULL, // ServicesActive database
                                     SC_MANAGER_ALL_ACCESS); // full access
    if (hSCM) {

        // Try to open the service
        SC_HANDLE hService = ::OpenService( hSCM, "NMap", SERVICE_ALL_ACCESS );
        if (hService)  {
			
			SERVICE_STATUS status;

			if( ( ret = ControlService( hService, SERVICE_CONTROL_STOP, &status ) ) == 0 ) {
			
				char msg[256];
				sprintf( msg, "Could not stop service - error code: %d", GetLastError() );
				MessageBox( msg, "Start NMap Service", MB_OK|MB_ICONERROR );
		
			} else
		       m_statusbar->SetWindowText( "NMap service stopped." );
	    
		} else {

			char msg[256];
			
			sprintf( msg, "Could not stop service - error code: %d", GetLastError() );
			MessageBox( msg, "Start NMap Service", MB_OK|MB_ICONERROR );
		}
    }    
    ::CloseServiceHandle(hSCM);
}

/**
 *
 */
void CServicePage::OnCloseupDatetimepicker1(NMHDR* pNMHDR, LRESULT* pResult) 
{
	*pResult = 0;
}

/**
 *
 */
void CServicePage::OnOutofmemorySlider1(NMHDR* pNMHDR, LRESULT* pResult) 
{
	// TODO: Add your control notification handler code here
	
	*pResult = 0;
}

/**
 *
 */
void CServicePage::OnEditchangeCombo1() 
{
}

/**
 *
 */
void CServicePage::OnSelendokCombo1() 
{
	switch( m_intervalfactor.GetCurSel() ) {

	case INTERVAL_MINUTES:
		m_interval.SetRange( 0, 60, true );
		m_interval.SetTicFreq( 10 );
		m_slidertext2.SetWindowText( "0                                               30                                                60" );
		break;

	case INTERVAL_HOURS:
		m_interval.SetRange( 0, 24, true );
		m_interval.SetTicFreq( 3 );
		m_slidertext2.SetWindowText( "0                                                12                                              24" );
		break;

	case INTERVAL_DAYS:  
		m_interval.SetRange( 0, 30, true );
		m_interval.SetTicFreq( 5 );
		m_slidertext2.SetWindowText( "0                                                15                                              30" );
		break;

	case INTERVAL_WEEKS:
		m_interval.SetRange( 0, 52, true );
		m_interval.SetTicFreq( 12 );
		m_slidertext2.SetWindowText( "0                                            26                                                   52" );
		break;

	case INTERVAL_MONTHS:
		m_interval.SetRange( 0, 12, true );
		m_interval.SetTicFreq( 3 );
		m_slidertext2.SetWindowText( "0                                                 6                                               12" );
		break;
	}
}

/**
 *
 */
void CServicePage::SetVisible( CTabCtrl* parent )
{
	// Set the window visible
	if( !IsWindow( m_hWnd ) ) {
		Create( IDD_DIALOG_SERVICE, parent );
	
		CRect rectParent;
		parent->GetWindowRect( rectParent );

		SetWindowPos( parent, 5, 25, rectParent.Width() - 10, rectParent.Height()-27, 
					  SWP_NOZORDER | SWP_NOACTIVATE );
	}
	ShowWindow( SW_SHOW );

	// Get the current registry parameters
	if(	GetRegistryArgs() ) {
		ParseServiceArgs();
		ParseNMapArgs();
	}

}

/**
 *
 */
void CServicePage::OnButton6()
{ 
	static char BASED_CODE szFilter[] = "NMap Service ConfFiles (*.cfg)|All Files (*.*)|*.*||";

	CFileDialog dlg( TRUE, "cfg", "*.cfg", OFN_LONGNAMES, szFilter, GetParent());
    
    if ( IDOK != dlg.DoModal() )
        return;	
	else {
		GetDlgItem( IDC_EDIT5 )->SetWindowText( dlg.GetPathName() );
	}
}

/**
 *
 */
void CServicePage::OnReleasedcaptureSlider1(NMHDR* pNMHDR, LRESULT* pResult) 
{
	char sPos[10];

	sprintf( sPos, "%d", m_interval.GetPos() );
	
	m_slidervalue.SetWindowText( sPos );	
	
	*pResult = 0;
}

/**
 *
 */
void CServicePage::OnChangeEdit3() 
{
	char sPos[10];
	
	m_slidervalue.GetWindowText( sPos, 10 );

	m_interval.SetPos( atoi( sPos ) );
}
